@@ -114,6 +114,10 @@ print.netdx <- function(x, digits = 3, ...) {
     cat("\nDissolution Diagnostics")
     cat("\n----------------------- \n")
     print(round(x$stats.table.dissolution, digits = digits))
+    if (x$coef.diss$model.type == "hetero") {
+      cat("----------------------- \n")
+      cat("* Heterogeneous dissolution model results averaged over")
+    }
   }
 
   invisible()
@@ -190,8 +194,8 @@ print.disscoef <- function(x, ...) {
   cat("\n=======================")
   cat("\nDissolution Model: "); ; print(x$dissolution)
   cat("Edge Duration:", x$duration)
-  cat("\nAdjusted Coefficient:", x$coef.adj)
   cat("\nCrude Coefficient:", x$coef.crude)
+  cat("\nAdjusted Coefficient:", x$coef.adj)
   cat("\nDeath rate:", x$d.rate)
   invisible()
 }
